# /u/sy/beebe/misc/gutenberg/race.awk, Sat Apr 18 15:05:03 1992
# Edit by Nelson H. F. Beebe <beebe@magna.math.utah.edu>
# ========================================================================
# Extract racial origin totals from uscen90.txt.  The matched lines
# occur twice, once as population values, and once as housing, so we
# must be careful to collect only the first one.  Nebraska is missing
# from the uscen90.txt file.
#
# Usage:
#	nawk -f race.awk uscen90.txt >xxx
# [18-Apr-1992]
# ========================================================================

/^   \*\*\* /			{ state = substr($0,8,20); gsub(/ /,"_",state)}
				# "District of Columbia" is longest name (20)

/^ *White/			{if (white[state] == "") white[state] = $NF }

/^ *Black/			{if (black[state] == "") black[state] = $NF }

/^ *American Indian/		{if (indian[state] == "") indian[state] = $NF }

/^ *Asian/			{if (asian[state] == "") asian[state] = $NF }

/^ *Hispanic/			{if (hispanic[state] == "") hispanic[state] = $NF }

/^ *Total population/		{if (population[state] == "") population[state] = $NF }

END {
    for (state in population)
        printf("%-20s%12s%12s%5.1f%12s%5.1f%12s%5.1f%12s%5.1f\n",
	       state, 
	       population[state],
	       white[state], percent(white[state],population[state]),
	       black[state], percent(black[state],population[state]),
	       indian[state], percent(indian[state],population[state]),
	       hispanic[state], percent(hispanic[state],population[state])) \
	       | "sort";
}


function percent(race,total)
{
    return (100.0 * strip_commas(race) / strip_commas(total))
}


function strip_commas(s, t)	# strip commas from strip_commasulation values
{
    t = s;
    gsub(/,/,"",t);
    return t;
}
